biom.table.Table.__subclasshook__ — biom-format.org

# biom-format.org

## biom.table.Table.__subclasshook__

static `Table.` `__subclasshook__`()

  Abstract classes can override this to customize issubclass().

  This is invoked early on by abc.ABCMeta.__subclasscheck__(). It should return True, False or NotImplemented. If it returns NotImplemented, the normal algorithm is used. Otherwise, it overrides the normal algorithm (and the outcome is cached).